==> derby-0.0.10.tgz: package/lib/View.server.js <==
var Dom, Model, View, empty, emptyModel, emptyRes, escapeInlineScript, loader, modelHelper, uglify;
var __slice = Array.prototype.slice;
Model = require('racer').Model;
uglify = require('uglify-js');
module.exports = View = require('./View');
Dom = require('./Dom');
modelHelper = require('./modelHelper');
loader = require('./loader');
empty = function() {};
emptyRes = {
  getHeader: empty,
  setHeader: empty,
  write: empty,
  end: empty
};
emptyModel = {
  get: empty,
  bundle: empty
};
escapeInlineScript = function(s) {
  return s.replace(/<\//g, '<\\/');
};
View.prototype.before = View.prototype.after = function() {};
View.prototype.inline = function(fn) {
  return this._inline += uglify("(" + fn + ")()") + ';';
};
View.prototype._load = function(isStatic, callback) {
  var self;
  if (loader.isProduction) {
    this._load = function(isStatic, callback) {
      return callback();
    };
  }
  if (isStatic) {
    return loader.views(this, this._root, this._clientName, callback);
  }
  self = this;
  return loader.js(this, this._appFilename, this._derbyOptions, function(obj) {
    self._root = obj.root;
    self._clientName = obj.clientName;
    self._jsFile = obj.jsFile;
    self._require = obj.require;
    return callback();
  });
};
View.prototype._init = function(model) {
  this.dom = new Dom(this.model = modelHelper.init(model));
  return this._idCount = 0;
};
View.prototype.render = function() {
  var arg, args, ctx, dom, isStatic, model, res, self, _i, _len;
  res = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
  if (res == null) {
    res = emptyRes;
  }
  for (_i = 0, _len = args.length; _i < _len; _i++) {
    arg = args[_i];
    if (arg instanceof Model) {
      model = arg;
    } else if (typeof arg === 'object') {
      ctx = arg;
    } else if (typeof arg === 'number') {
      res.statusCode = arg;
    } else if (typeof arg === 'boolean') {
      isStatic = arg;
    }
  }
  if (model == null) {
    model = emptyModel;
  }
  self = this;
  this._init(model);
  dom = this.dom;
  return this._load(isStatic, function() {
    return loader.css(self._root, self._clientName, function(css) {
      return self._render(res, model, ctx, isStatic, dom, css);
    });
  });
};
View.prototype._render = function(res, model, ctx, isStatic, dom, css) {
  var clientName, doctype, head, header, initEnd, initStart, scripts, tail, title;
  if (!res.getHeader('content-type')) {
    res.setHeader('Content-Type', 'text/html; charset=utf-8');
  }
  doctype = this.get('doctype', ctx) || '<!DOCTYPE html><meta charset=utf-8>';
  title = View.htmlEscape(this.get('title$s', ctx)) || 'Derby app';
  head = this.get('head', ctx);
  header = this.get('header', ctx);
  if (css) {
    css = "<style>" + css + "</style>";
  }
  res.write("" + doctype + "<title>" + title + "</title>" + head + css + header);
  res.write(this.get('body', ctx));
  clientName = this._clientName;
  scripts = "<script>function $(i){return document.getElementById(i)}" + escapeInlineScript(this._inline);
  if (!isStatic) {
    scripts += "function " + clientName + "(){" + clientName + "=1}";
  }
  scripts += "</script>" + this.get('script', ctx);
  if (!isStatic) {
    scripts += "<script defer async onload=" + clientName + "() src=" + this._jsFile + "></script>";
  }
  res.write(scripts);
  tail = this.get('tail', ctx);
  if (isStatic) {
    return res.end(tail);
  }
  initStart = "<script>(function(){function f(){setTimeout(function(){" + ("" + clientName + "=require('./" + this._require + "')(" + this._idCount + ",") + JSON.stringify(this._paths) + ',' + JSON.stringify(this._partialIds) + ',' + JSON.stringify(this._aliases) + ',' + JSON.stringify(this._depths) + ',';
  initEnd = ',' + JSON.stringify(model.__events.get()) + ',' + JSON.stringify(dom.events.get()) + (")},0)}" + clientName + "===1?f():" + clientName + "=f})()</script>" + tail);
  return model.bundle(function(bundle) {
    return res.end(initStart + escapeInlineScript(bundle) + initEnd);
  });
};

==> derby-0.1.0.tgz: package/lib/View.server.js <==
var Dom, Model, View, empty, emptyModel, emptyRes, escapeInlineScript, htmlEscape, loader, modelHelper, uglify;
var __slice = Array.prototype.slice;
Model = require('racer').Model;
uglify = require('uglify-js');
module.exports = View = require('./View');
htmlEscape = require('./html').htmlEscape;
Dom = require('./Dom');
modelHelper = require('./modelHelper');
loader = require('./loader');
empty = function() {};
emptyRes = {
  getHeader: empty,
  setHeader: empty,
  write: empty,
  end: empty
};
emptyModel = {
  get: empty,
  bundle: empty
};
escapeInlineScript = function(s) {
  return s.replace(/<\//g, '<\\/');
};
View.prototype.before = View.prototype.after = function() {};
View.prototype.inline = function(fn) {
  return this._inline += uglify("(" + fn + ")()") + ';';
};
View.prototype._load = function(isStatic, callback) {
  var self;
  if (loader.isProduction) {
    this._load = function(isStatic, callback) {
      return callback();
    };
  }
  if (isStatic) {
    return loader.views(this, this._root, this._clientName, callback);
  }
  self = this;
  return loader.js(this, this._appFilename, this._derbyOptions, function(obj) {
    self._root = obj.root;
    self._clientName = obj.clientName;
    self._jsFile = obj.jsFile;
    self._require = obj.require;
    return callback();
  });
};
View.prototype._init = function(model) {
  this.dom = new Dom(this.model = modelHelper.init(model));
  return this._idCount = 0;
};
View.prototype.render = function() {
  var arg, args, ctx, dom, isStatic, model, res, self, _i, _len;
  res = arguments[0], args = 2 <= arguments.length ? __slice.call(arguments, 1) : [];
  if (res == null) {
    res = emptyRes;
  }
  for (_i = 0, _len = args.length; _i < _len; _i++) {
    arg = args[_i];
    if (arg instanceof Model) {
      model = arg;
    } else if (typeof arg === 'object') {
      ctx = arg;
    } else if (typeof arg === 'number') {
      res.statusCode = arg;
    } else if (typeof arg === 'boolean') {
      isStatic = arg;
    }
  }
  if (model == null) {
    model = emptyModel;
  }
  self = this;
  this._init(model);
  dom = this.dom;
  return this._load(isStatic, function() {
    return loader.css(self._root, self._clientName, function(css) {
      return self._render(res, model, ctx, isStatic, dom, css);
    });
  });
};
View.prototype._render = function(res, model, ctx, isStatic, dom, css) {
  var clientName, doctype, head, header, initEnd, initStart, scripts, tail, title;
  if (!res.getHeader('content-type')) {
    res.setHeader('Content-Type', 'text/html; charset=utf-8');
  }
  doctype = this.get('doctype', ctx) || '<!DOCTYPE html><meta charset=utf-8>';
  title = htmlEscape(this.get('title$s', ctx)) || 'Derby app';
  head = this.get('head', ctx);
  header = this.get('header', ctx);
  if (css) {
    css = "<style>" + css + "</style>";
  }
  res.write("" + doctype + "<title>" + title + "</title>" + head + css + header);
  res.write(this.get('body', ctx));
  clientName = this._clientName;
  scripts = "<script>function $(i){return document.getElementById(i)}" + escapeInlineScript(this._inline);
  if (!isStatic) {
    scripts += "function " + clientName + "(){" + clientName + "=1}";
  }
  scripts += "</script>" + this.get('scripts', ctx);
  if (!isStatic) {
    scripts += "<script defer async onload=" + clientName + "() src=" + this._jsFile + "></script>";
  }
  res.write(scripts);
  tail = this.get('tail', ctx);
  if (isStatic) {
    return res.end(tail);
  }
  initStart = "<script>(function(){function f(){setTimeout(function(){" + ("" + clientName + "=require('./" + this._require + "')(" + this._idCount + ",") + JSON.stringify(this._paths) + ',' + JSON.stringify(this._aliases) + ',' + model.__pathMap.count + ',' + JSON.stringify(model.__pathMap.ids) + ',';
  initEnd = ',' + JSON.stringify(model.__events.get()) + ',' + JSON.stringify(dom.events.get()) + (")},0)}" + clientName + "===1?f():" + clientName + "=f})()</script>" + tail);
  return model.bundle(function(bundle) {
    return res.end(initStart + escapeInlineScript(bundle) + initEnd);
  });
};
